==> blancoCsv-1.1.0-src.zip: src/blanco/csv/resourcebundle/BlancoCsvIOExceptionResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.csv.resourcebundle;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoCsvIOException]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 * m̃P[<BR>
 * <UL>
 * <LI>ja
 * </UL>
 */
public class BlancoCsvIOExceptionResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoCsvIOExceptionResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoCsvIOException]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoCsvIOExceptionResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoCsvIOException");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoCsvIOExceptionResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoCsvIOException]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoCsvIOExceptionResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoCsvIOException", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoCsvIOExceptionResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoCsvIOException]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoCsvIOExceptionResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoCsvIOException", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[BlancoCsvIOException], key[PACKAGE.PREFIX]
     *
     * [.io] (ja)<br>
     *
     * @return key[PACKAGE.PREFIX]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getPackagePrefix() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = ".io";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("PACKAGE.PREFIX");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }

    /**
     * bundle[BlancoCsvIOException], key[CLASS_NAME]
     *
     * [BlancoCsvIOException] (ja)<br>
     *
     * @return key[CLASS_NAME]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getClassName() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "BlancoCsvIOException";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CLASS_NAME");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }

    /**
     * bundle[BlancoCsvIOException], key[SUPERCLASS_NAME]
     *
     * [java.lang.Exception] (ja)<br>
     *
     * @return key[SUPERCLASS_NAME]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getSuperclassName() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "java.lang.Exception";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("SUPERCLASS_NAME");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }

    /**
     * bundle[BlancoCsvIOException], key[FILECOMMENT]
     *
     * [blancoCsvNXsɔONXłB&lt;br&gt;] (ja)<br>
     *
     * @return key[FILECOMMENT]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getFilecomment() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "blancoCsvNXsɔONXłB<br>";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("FILECOMMENT");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }

    /**
     * bundle[BlancoCsvIOException], key[CLASSCOMMENT.01]
     *
     * [blancoCsvNXsɔONXłB&lt;br&gt;] (ja)<br>
     *
     * @return key[CLASSCOMMENT.01]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getClasscomment01() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "blancoCsvNXsɔONXłB<br>";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CLASSCOMMENT.01");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }

    /**
     * bundle[BlancoCsvIOException], key[CLASSCOMMENT.02]
     *
     * [^E`FbŇʂُłꍇȂǂɂ̗O͔܂B] (ja)<br>
     *
     * @return key[CLASSCOMMENT.02]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getClasscomment02() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "^E`FbŇʂُłꍇȂǂɂ̗O͔܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CLASSCOMMENT.02");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }

    /**
     * bundle[BlancoCsvIOException], key[CONSTRUCTOR.01.ARG.01.TYPE]
     *
     * [java.lang.String] (ja)<br>
     *
     * @return key[CONSTRUCTOR.01.ARG.01.TYPE]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getConstructor01Arg01Type() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "java.lang.String";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CONSTRUCTOR.01.ARG.01.TYPE");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }

    /**
     * bundle[BlancoCsvIOException], key[CONSTRUCTOR.01.LINE.01]
     *
     * [super(message);] (ja)<br>
     *
     * @return key[CONSTRUCTOR.01.LINE.01]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getConstructor01Line01() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "super(message);";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CONSTRUCTOR.01.LINE.01");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }
}

==> blancoCsv-1.2.1-src.zip: src/blanco/csv/resourcebundle/BlancoCsvIOExceptionResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.csv.resourcebundle;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoCsvIOException]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 * m̃P[<BR>
 * <UL>
 * <LI>ja
 * </UL>
 */
public class BlancoCsvIOExceptionResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoCsvIOExceptionResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoCsvIOException]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoCsvIOExceptionResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/csv/resourcebundle/BlancoCsvIOException");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoCsvIOExceptionResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoCsvIOException]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoCsvIOExceptionResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/csv/resourcebundle/BlancoCsvIOException", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoCsvIOExceptionResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoCsvIOException]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoCsvIOExceptionResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/csv/resourcebundle/BlancoCsvIOException", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[BlancoCsvIOException], key[PACKAGE.PREFIX]
     *
     * [.io] (ja)<br>
     *
     * @return key[PACKAGE.PREFIX]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getPackagePrefix() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = ".io";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("PACKAGE.PREFIX");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }

    /**
     * bundle[BlancoCsvIOException], key[CLASS_NAME]
     *
     * [BlancoCsvIOException] (ja)<br>
     *
     * @return key[CLASS_NAME]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getClassName() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "BlancoCsvIOException";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CLASS_NAME");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }

    /**
     * bundle[BlancoCsvIOException], key[SUPERCLASS_NAME]
     *
     * [java.lang.Exception] (ja)<br>
     *
     * @return key[SUPERCLASS_NAME]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getSuperclassName() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "java.lang.Exception";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("SUPERCLASS_NAME");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }

    /**
     * bundle[BlancoCsvIOException], key[CLASSCOMMENT.01]
     *
     * [blancoCsvNXsɔONXłB] (ja)<br>
     *
     * @return key[CLASSCOMMENT.01]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getClasscomment01() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "blancoCsvNXsɔONXłB";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CLASSCOMMENT.01");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }

    /**
     * bundle[BlancoCsvIOException], key[CLASSCOMMENT.02]
     *
     * [^E`FbŇʂُłꍇȂǂɂ̗O͔܂B] (ja)<br>
     *
     * @return key[CLASSCOMMENT.02]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getClasscomment02() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "^E`FbŇʂُłꍇȂǂɂ̗O͔܂B";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CLASSCOMMENT.02");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }

    /**
     * bundle[BlancoCsvIOException], key[CONSTRUCTOR.01.ARG.01.TYPE]
     *
     * [java.lang.String] (ja)<br>
     *
     * @return key[CONSTRUCTOR.01.ARG.01.TYPE]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getConstructor01Arg01Type() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "java.lang.String";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CONSTRUCTOR.01.ARG.01.TYPE");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }

    /**
     * bundle[BlancoCsvIOException], key[CONSTRUCTOR.01.LINE.01]
     *
     * [super(message);] (ja)<br>
     *
     * @return key[CONSTRUCTOR.01.LINE.01]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getConstructor01Line01() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "super(message);";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CONSTRUCTOR.01.LINE.01");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }
}
